# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .options.LogCostOptions import LogCostOptions


class LogCost:
    base: float
    adds: List[float]
    subs: Optional[List[float]] = None

    def __init__(
        self,
        base: float,
        adds: List[float],
        options: Optional[LogCostOptions] = LogCostOptions(),
    ):
        self.base = base
        self.adds = adds
        self.subs = options.subs if options.subs else None

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.base is not None:
            properties["base"] = self.base
        if self.adds is not None:
            properties["adds"] = self.adds
        if self.subs is not None:
            properties["subs"] = self.subs

        return properties
